# Changelog

## v1.4.0 - 2026-04-05

### Features
- Phase 1 context keeper — metadata, lint, trust history, extraction patterns

### Other
- Merge branch 'main' of https://github.com/CptPlastic/lore-book
- Bump scoop to 1.3.1 and enhance packaging script

## v1.3.1 - 2026-03-26

### Other
- Import existing CHRONICLE during onboarding
- install to app-local site and set PYTHONPATH
- Add Scoop bucket sync workflow; remove template
- Add Scoop bucket template and docs
- Add Windows packaging & installer support

## v1.3.0 - 2026-03-25

- Maintenance release.

## v1.2.11 - 2026-03-25

### Other
- Remove commit validation; update CHRONICLE
- Merge branch 'main' of https://github.com/CptPlastic/lore-book
- Add PyPI publish job and CHRONICLE notes

## v1.2.10 - 2026-03-25

### Documentation
- add demo/overview presentation page

### Other
- Merge branch 'main' of https://github.com/CptPlastic/lore-book
- Add CHRONICLE sync & automated releases
- Add demo slide deck (site/demo.html)

